@@ -7,8 +7,8 @@ from __future__ import annotations
 
 from typing import Any
 
-from anta.tests.stun import VerifyStunClient
-from tests.lib.anta import test  # noqa: F401; pylint: disable=W0611
+from anta.tests.stun import VerifyStunClient, VerifyStunServer
+from tests.units.anta_tests import test
 
 DATA: list[dict[str, Any]] = [
     {
@@ -173,4 +173,61 @@ DATA: list[dict[str, Any]] = [
             ],
         },
     },
+    {
+        "name": "success",
+        "test": VerifyStunServer,
+        "eos_data": [
+            {
+                "enabled": True,
+                "pid": 1895,
+            }
+        ],
+        "inputs": {},
+        "expected": {"result": "success"},
+    },
+    {
+        "name": "failure-disabled",
+        "test": VerifyStunServer,
+        "eos_data": [
+            {
+                "enabled": False,
+                "pid": 1895,
+            }
+        ],
+        "inputs": {},
+        "expected": {
+            "result": "failure",
+            "messages": ["STUN server status is disabled."],
+        },
+    },
+    {
+        "name": "failure-not-running",
+        "test": VerifyStunServer,
+        "eos_data": [
+            {
+                "enabled": True,
+                "pid": 0,
+            }
+        ],
+        "inputs": {},
+        "expected": {
+            "result": "failure",
+            "messages": ["STUN server is not running."],
+        },
+    },
+    {
+        "name": "failure-not-running-disabled",
+        "test": VerifyStunServer,
+        "eos_data": [
+            {
+                "enabled": False,
+                "pid": 0,
+            }
+        ],
+        "inputs": {},
+        "expected": {
+            "result": "failure",
+            "messages": ["STUN server status is disabled and not running."],
+        },
+    },
 ]
